/*
 * vitals.h -- represent the vital information (i.e. uniquiely identifying
 *             remarks, model number, etc.) for a disk
 *
 * Copyright 2007-2008 Red Hat, Inc.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author(s): Peter Jones <pjones@redhat.com>
 */

#ifndef NASH_PRIV_VITALS_H
#define NASH_PRIV_VITALS_H 1

#ifdef _GNU_SOURCE
#define _GNU_SOURCE_DEFINED
#else
#define _GNU_SOURCE 1
#endif

#include <nash.h>

struct nash_bdev_vitals {
    int refcount;
    uint32_t hash;
    int type;
    char *name;

    union {
        /* DEV_TYPE_DISK */
        struct {
            char *unique_id;
            char *disk_device_node;
            char *disk_model;
            char *disk_vendor;
            char *disk_probe_module;
            char *disk_probe_name;
        };
        /* DEV_TYPE_DM_MPATH, DEV_TYPE_DM_RAID */
        struct {
            char *dmname;
        };
        /*  DEV_TYPE_LVM2_PV */
        struct {
            char *unique_id;
        };
        /* nothing for DEV_TYPE_PARTITION */
        /* DEV_TYPE_LVM2_VG */
        struct {
            char *unique_id;
            char *vg_name;
        };
        /* DEV_TYPE_LVM2_LV */
        struct {
            char *unique_id;
            char *lv_name;
        };
        /* DEV_TYPE_FS */
        struct {
            char *unique_id;
            char *fs_type;
            char *fs_label;
            char *fs_options;
        };
        /* XXX FIXME: DEV_TYPE_MD_RAID */
    };
};

extern void nash_bdev_vitals_free(nashContext *nc,
        struct nash_bdev_vitals *vitals);
extern void nash_vitals_incref(struct nash_bdev_vitals *vitals);
extern void nash_vitals_decref(nashContext *nc,
        struct nash_bdev_vitals *vitals);
extern struct nash_bdev_vitals *nash_bdev_vitals_alloc(void);
extern struct nash_bdev_vitals *nash_bdev_vitals_from_blkent(nashContext *nc,
    struct blkent *blkent);
extern int nash_vitals_initialize_probes(void);
extern void nash_vitals_destroy_probes(void);
extern struct nash_list *nash_vitals_probe(nashContext *nc,
        struct nash_dev_node *node);
extern int nash_bdev_vitals_type_cmp(struct nash_bdev_vitals *v0,
    struct nash_bdev_vitals *v1);
extern int nash_bdev_vitals_cmp(nashContext *nc, struct nash_bdev_vitals *v0,
    struct nash_bdev_vitals *v1);

extern int nash_vitals_cache_init(nashContext *nc);
extern void nash_vitals_cache_destroy(nashContext *nc);

struct nash_vitals_cache;

#endif /* NASH_PRIV_VITALS_H */
/*
 * vim:ts=8:sw=4:sts=4:et
 */
